CREATE TABLE [dbo].[UserTBL](
  [UserId] [uniqueidentifier] NOT NULL,
  [UserName] [nvarchar](256) COLLATE Japanese_CI_AS NOT NULL,
  [DispName] [nvarchar](256) COLLATE Japanese_CI_AS NOT NULL,
  [ThemeName] [nvarchar](50) COLLATE Japanese_CI_AS NOT NULL,
  [CreateDate] [datetime] NOT NULL,
  CONSTRAINT [PK_UserTBL] PRIMARY KEY CLUSTERED (
    [UserId] ASC
  ) WITH (PAD_INDEX  = OFF, IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE PROCEDURE [dbo].[UserTBL_GetUser] (
  @UserId uniqueidentifier
) AS
SELECT UserId, UserName, DispName, ThemeName, CreateDate
  FROM UserTBL WHERE (UserId = @UserId);
GO
CREATE PROCEDURE [dbo].[UserTBL_UpdateUser] (
  @UserId uniqueidentifier,
  @UserName nvarchar(256),
  @DispName nvarchar(256),
  @ThemeName nvarchar(50)
) AS
IF (SELECT COUNT(*) FROM UserTBL WHERE UserId = @UserId) = 0
BEGIN
  INSERT INTO UserTBL (
      UserId, UserName, DispName, ThemeName, CreateDate
    ) VALUES (
      @UserId, @UserName, @DispName, @ThemeName, GETDATE());
END ELSE BEGIN
  UPDATE UserTBL SET
    UserName = @UserName, DispName = @DispName, ThemeName = @ThemeName
    WHERE (UserId = @UserId);
END
GO
CREATE TABLE [dbo].[BlogCategoryTBL](
  [CategoryId] [uniqueidentifier] NOT NULL,
  [CategoryName] [nvarchar](256) COLLATE Japanese_CI_AS NOT NULL,
  [IsDelete] [bit] NOT NULL,
  [CreateDate] [datetime] NOT NULL,
  CONSTRAINT [PK_BlogCategoryTBL] PRIMARY KEY CLUSTERED (
    [CategoryId] ASC
  ) WITH (PAD_INDEX  = OFF, IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE PROCEDURE [dbo].[BlogCategoryTBL_GetCategories]
AS
SELECT CategoryId, CategoryName, IsDelete, CreateDate
 FROM BlogCategoryTBL ORDER BY CategoryName;
GO
CREATE PROCEDURE [dbo].[BlogCategoryTBL_UpdateCategory] (
  @CategoryId uniqueidentifier,
  @CategoryName nvarchar(256)
) AS
IF (SELECT COUNT(*) FROM BlogCategoryTBL WHERE (CategoryId = @CategoryId)) = 0
BEGIN
  INSERT INTO BlogCategoryTBL (
      CategoryId, CategoryName, IsDelete, CreateDate
    ) VALUES (
      @CategoryId, @CategoryName, 0, GETDATE());
END ELSE BEGIN
  UPDATE BlogCategoryTBL
    SET CategoryName = @CategoryName WHERE (CategoryId = @CategoryId);
END
GO
CREATE TABLE [dbo].[BlogEntryTBL](
  [EntryId] [uniqueidentifier] NOT NULL,
  [UserId] [uniqueidentifier] NOT NULL,
  [CategoryId] [uniqueidentifier] NOT NULL,
  [EntryTitle] [nvarchar](256) COLLATE Japanese_CI_AS NOT NULL,
  [EntryBody] [ntext] COLLATE Japanese_CI_AS NOT NULL,
  [Comment] [int] NOT NULL,
  [HasAttach] [bit] NOT NULL,
  [IsDelete] [bit] NOT NULL,
  [CreateDate] [datetime] NOT NULL,
  CONSTRAINT [PK_BlogEntryTBL] PRIMARY KEY CLUSTERED (
    [EntryId] ASC
  ) WITH (PAD_INDEX  = OFF, IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
CREATE PROCEDURE [dbo].[BlogEntryTBL_GetEntry] (
  @EntryId uniqueidentifier
) AS
SELECT A.EntryId, A.UserId, A.CategoryId, A.EntryTitle, A.EntryBody, A.Comment, A.HasAttach, A.IsDelete, A.CreateDate, B.CategoryName
  FROM BlogEntryTBL A
    INNER JOIN BlogCategoryTBL B ON A.CategoryId = B.CategoryId
  WHERE (A.EntryId = @EntryId);
GO
CREATE PROCEDURE [dbo].[BlogEntryTBL_UpdateEntry] (
  @EntryId uniqueidentifier,
  @UserId uniqueidentifier,
  @CategoryId uniqueidentifier,
  @EntryTitle nvarchar(256),
  @EntryBody ntext,
  @HasAttach bit
) AS
IF (SELECT COUNT(*) FROM BlogEntryTBL WHERE (EntryId = @EntryId)) = 0
BEGIN
  INSERT INTO  BlogEntryTBL (
    EntryId, UserId, CategoryId, EntryTitle, EntryBody, Comment, HasAttach, IsDelete, CreateDate
  ) VALUES (
    @EntryId, @UserId, @CategoryId, @EntryTitle, @EntryBody, 0, @HasAttach, 0, GETDATE());
END ELSE BEGIN
  UPDATE BlogEntryTBL
    SET CategoryId = @CategoryId, UserId = @UserId, EntryTitle = @EntryTitle, EntryBody = @EntryBody, HasAttach = @HasAttach
    WHERE (EntryId = @EntryId);
END
GO
CREATE PROCEDURE [dbo].[BlogEntryTBL_DeleteEntry] (
  @EntryId uniqueidentifier
) AS
UPDATE BlogEntryTBL SET IsDelete = 1 WHERE (EntryId = @EntryId);
GO
CREATE PROCEDURE [dbo].[BlogEntryTBL_GetEntryDays] (
  @Year int,
  @Month int
) AS
SELECT CONVERT(nvarchar(10),CreateDate,111) AS EntryDay, COUNT(*) AS EntryCount
  FROM BlogEntryTBL
  WHERE (DATEPART(yyyy,CreateDate) = @Year AND DATEPART(mm,CreateDate) = @Month)
  GROUP BY CONVERT(nvarchar(10),CreateDate,111);
GO
CREATE TABLE [dbo].[BlogCommentTBL](
  [EntryId] [uniqueidentifier] NOT NULL,
  [CommentId] [int] NOT NULL,
  [DispName] [nvarchar](256) COLLATE Japanese_CI_AS NOT NULL,
  [CommentBody] [ntext] COLLATE Japanese_CI_AS NOT NULL,
  [IsDelete] [bit] NOT NULL,
  [CreateDate] [datetime] NOT NULL,
  CONSTRAINT [PK_BlogCommentTBL] PRIMARY KEY CLUSTERED (
    [EntryId] ASC,
    [CommentId] ASC
  ) WITH (PAD_INDEX  = OFF, IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
CREATE PROCEDURE [dbo].[BlogCommentTBL_GetComments] (
  @EntryId uniqueidentifier
) AS
SELECT EntryId, CommentId, DispName, CommentBody, CreateDate, IsDelete
  FROM BlogCommentTBL WHERE (EntryId = @EntryId) AND (IsDelete = 0)
  ORDER BY CommentId;
GO
CREATE PROCEDURE [dbo].[BlogCommentTBL_AddComment] (
  @EntryId uniqueidentifier,
  @DispName nvarchar(256),
  @CommentBody ntext
) AS
DECLARE @CommentId [int]
DECLARE @Comment [int]
IF (SELECT COUNT(*) FROM BlogEntryTBL WHERE (EntryId = @EntryId)) > 0
BEGIN
  SELECT @Comment = (SELECT COUNT(*)+1 FROM BlogCommentTBL WHERE (EntryId = @EntryId) AND (IsDelete = 0));
  UPDATE BlogEntryTBL SET Comment = @Comment WHERE (EntryId = @EntryId);
  SET @CommentId = 1
  IF (SELECT COUNT(*) FROM BlogCommentTBL WHERE (EntryId = @EntryId)) > 0
    SELECT @CommentId = (SELECT MAX(CommentId)+1 FROM BlogCommentTBL WHERE (EntryId = @EntryId))
  INSERT INTO  BlogCommentTBL (
    EntryId, CommentId, DispName, CommentBody, CreateDate, IsDelete
  ) VALUES (
    @EntryId, @CommentId,@DispName,@CommentBody, GETDATE(), 0);
END
GO
CREATE PROCEDURE [dbo].[BlogCommentTBL_DeleteComment] (
  @EntryId uniqueidentifier,
  @CommentId int
) AS
DECLARE @Comment int
SELECT @Comment = (SELECT COUNT(*)-1 FROM BlogCommentTBL
  WHERE (EntryId = @EntryId) AND (IsDelete = 0));
UPDATE BlogEntryTBL SET Comment = @Comment WHERE (EntryId = @EntryId);
UPDATE BlogCommentTBL SET IsDelete = 1 WHERE (EntryId = @EntryId) AND (CommentId = @CommentId);
GO
CREATE TABLE [dbo].[BlogAttachTBL](
  [AttachId] [uniqueidentifier] NOT NULL,
  [FileName] [nvarchar](256) COLLATE Japanese_CI_AS NOT NULL,
  [FileSize] [int] NOT NULL,
  [FileData] [image] NOT NULL,
  [ContentType] [nvarchar](256) COLLATE Japanese_CI_AS NOT NULL,
  [CreateDate] [datetime] NOT NULL,
  CONSTRAINT [PK_BlogAttachTBL] PRIMARY KEY CLUSTERED (
    [AttachId] ASC
  ) WITH (PAD_INDEX  = OFF, IGNORE_DUP_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
CREATE PROCEDURE [dbo].[BlogAttachTBL_GetAttach] (
  @AttachId uniqueidentifier
) AS
SELECT AttachId, FileName, FileSize, FileData, ContentType, CreateDate
  FROM BlogAttachTBL WHERE (AttachId = @AttachId);
GO
CREATE PROCEDURE [dbo].[BlogAttachTBL_UpdateAttach] (
  @AttachId uniqueidentifier,
  @FileName nvarchar(256),
  @FileSize int,
  @FileData image,
  @ContentType nvarchar(256)
) AS
IF (SELECT COUNT(*) FROM BlogAttachTBL WHERE (AttachId = @AttachId)) = 0
BEGIN
  INSERT INTO  BlogAttachTBL (
    AttachId, FileName, FileSize, FileData, ContentType, CreateDate
  ) VALUES (
    @AttachId,@FileName,@FileSize,@FileData, @ContentType, GETDATE());
END ELSE BEGIN
  UPDATE  BlogAttachTBL
    SET FileName = @FileName, FileSize = @FileSize, FileData = @FileData, ContentType = @ContentType, CreateDate = GETDATE()
    WHERE (AttachId = @AttachId);
END
GO
CREATE VIEW [dbo].[BlogEntryView]
AS
SELECT dbo.BlogEntryTBL.EntryId,
       dbo.BlogEntryTBL.EntryTitle,
       dbo.BlogEntryTBL.EntryBody,
       dbo.BlogEntryTBL.Comment,
       dbo.BlogEntryTBL.HasAttach,
       dbo.BlogEntryTBL.IsDelete,
       dbo.BlogEntryTBL.CreateDate,
       dbo.UserTBL.UserId,
       dbo.UserTBL.DispName,
       dbo.BlogCategoryTBL.CategoryId, 
       dbo.BlogCategoryTBL.CategoryName
FROM dbo.BlogEntryTBL INNER JOIN
     dbo.UserTBL ON dbo.BlogEntryTBL.UserId = dbo.UserTBL.UserId INNER JOIN
     dbo.BlogCategoryTBL ON 
     dbo.BlogEntryTBL.CategoryId = dbo.BlogCategoryTBL.CategoryId
GO
CREATE PROCEDURE [dbo].[BlogEntryView_GetEntryView] (
  @EntryId uniqueidentifier
) AS
SELECT EntryId, EntryTitle, EntryBody, Comment, HasAttach, IsDelete, CreateDate, UserId, DispName, CategoryId, CategoryName
  FROM BlogEntryView
  WHERE (EntryId = @EntryId);
GO
CREATE PROCEDURE [dbo].[BlogEntryView_GetEntries] (
  @Count int = 0
) AS
IF @Count = 0
BEGIN
  SELECT EntryId, EntryTitle, EntryBody, Comment, HasAttach, IsDelete, CreateDate, UserId, DispName, CategoryId, CategoryName
    FROM BlogEntryView
    WHERE (IsDelete = 0) ORDER BY CreateDate DESC;
END ELSE BEGIN
  SELECT TOP(@Count) EntryId, EntryTitle, EntryBody, Comment, HasAttach, IsDelete, CreateDate, UserId, DispName, CategoryId, CategoryName
    FROM BlogEntryView
    WHERE (IsDelete = 0) ORDER BY CreateDate DESC;
END
GO
CREATE PROCEDURE [dbo].[BlogEntryView_GetEntriesByCategory] (
  @CategoryId uniqueidentifier
) AS
SELECT EntryId, EntryTitle, EntryBody, Comment, HasAttach, IsDelete, CreateDate, UserId, DispName, CategoryId, CategoryName
  FROM BlogEntryView
  WHERE (CategoryId = @CategoryId) AND (IsDelete = 0);
GO
CREATE PROCEDURE [dbo].[BlogEntryView_GetEntriesByDate] (
  @Year int,
  @Month int,
  @Day int
) AS
SELECT EntryId, EntryTitle, EntryBody, Comment, HasAttach, IsDelete, CreateDate, UserId, DispName, CategoryId, CategoryName
  FROM BlogEntryView
  WHERE (IsDelete = 0) AND YEAR(CreateDate) = @Year AND MONTH(CreateDate) = @Month AND DAY(CreateDate) = @Day
  ORDER BY CreateDate DESC;
GO
